@@ -92,14 +92,14 @@ pub struct Config {
 #[derive(Serialize, Deserialize, Clone, Eq, PartialEq)]
 pub(crate) struct SerialisableCertificate {
     /// DER encoded certificate
-    pub cert_der: Bytes,
+    cert_der: Bytes,
     /// DER encoded private key
-    pub key_der: Bytes,
+    key_der: Bytes,
 }
 
 impl SerialisableCertificate {
     /// Returns a new Certificate that is valid for the list of domain names provided
-    pub fn new(domains: impl Into<Vec<String>>) -> Result<Self> {
+    pub(crate) fn new(domains: impl Into<Vec<String>>) -> Result<Self> {
         let cert = rcgen::generate_simple_self_signed(domains)?;
         Ok(Self {
             cert_der: cert.serialize_der()?.into(),
@@ -112,7 +112,9 @@ impl SerialisableCertificate {
     /// # Errors
     /// Returns [CertificateParseError](Error::CertificateParseError) if the inputs
     /// cannot be parsed
-    pub fn obtain_priv_key_and_cert(&self) -> Result<(quinn::PrivateKey, quinn::Certificate)> {
+    pub(crate) fn obtain_priv_key_and_cert(
+        &self,
+    ) -> Result<(quinn::PrivateKey, quinn::Certificate)> {
         Ok((
             quinn::PrivateKey::from_der(&self.key_der).map_err(|_| Error::CertificatePkParse)?,
             quinn::Certificate::from_der(&self.cert_der).map_err(|_| Error::CertificateParse)?,
